@@ -8,7 +8,7 @@ import {
   VISIBILITY_STATUSES,
 } from '@tamanu/constants';
 import { getNoteWithType } from '@tamanu/shared/utils/notes';
-import { InvalidOperationError } from '@tamanu/shared/errors';
+import { InvalidOperationError } from '@tamanu/errors';
 import { getCurrentDateTimeString } from '@tamanu/utils/dateTime';
 
 import { Model } from './Model';
@@ -102,7 +102,7 @@ export class ImagingRequest extends Model {
           },
         },
         hooks: {
-          afterUpdate: async (imagingRequest: ImagingRequest) => {
+          afterUpdate: async (imagingRequest: ImagingRequest, options) => {
             const shouldPushNotification = [IMAGING_REQUEST_STATUS_TYPES.COMPLETED].includes(
               imagingRequest.status,
             );
@@ -113,7 +113,8 @@ export class ImagingRequest extends Model {
             ) {
               await models.Notification.pushNotification(
                 NOTIFICATION_TYPES.IMAGING_REQUEST,
-                imagingRequest,
+                imagingRequest.dataValues,
+                { transaction: options.transaction },
               );
             }
 
@@ -132,6 +133,7 @@ export class ImagingRequest extends Model {
                     id: imagingRequest.id,
                   },
                 },
+                transaction: options.transaction,
               });
             }
           },
@@ -224,7 +226,7 @@ export class ImagingRequest extends Model {
     );
   }
 
-  static buildSyncLookupQueryDetails() {
+  static async buildSyncLookupQueryDetails() {
     return buildEncounterLinkedLookupFilter(this);
   }
 }
